@@ -4,7 +4,7 @@ describe 'keystone::wsgi::apache' do
 
   let :global_facts do
     {
-      :processorcount => 42,
+      :os_workers     => 8,
       :concat_basedir => '/var/lib/puppet/concat',
       :fqdn           => 'some.host.tld'
     }
@@ -193,8 +193,23 @@ describe 'keystone::wsgi::apache' do
       it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
     end
 
+    describe 'when servername_admin is overriden' do
+      let :params do
+        {
+          :servername            => 'dummy1.host',
+          :servername_admin      => 'dummy2.host',
+        }
+      end
 
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_admin').with(
+        'servername'                  => 'dummy2.host',
+      )}
 
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_main').with(
+        'servername'                  => 'dummy1.host',
+      )}
+
+    end
 
     describe 'when overriding parameters using same port' do
       let :params do
@@ -296,6 +311,42 @@ describe 'keystone::wsgi::apache' do
       )}
     end
 
+    describe 'when setting ssl cert and key' do
+      let :params do
+        {
+          :ssl_cert => 'some cert',
+          :ssl_key  => 'some key',
+        }
+      end
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_main').with(
+          'ssl_cert' => 'some cert',
+          'ssl_key'  => 'some key',
+          )}
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_admin').with(
+          'ssl_cert' => 'some cert',
+          'ssl_key'  => 'some key',
+          )}
+    end
+
+    describe 'when setting different ssl cert and key for admin' do
+      let :params do
+        {
+          :ssl_cert       => 'some cert',
+          :ssl_key        => 'some key',
+          :ssl_cert_admin => 'some cert admin',
+          :ssl_key_admin  => 'some key admin',
+        }
+      end
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_main').with(
+          'ssl_cert' => 'some cert',
+          'ssl_key'  => 'some key',
+          )}
+      it { is_expected.to contain_apache__vhost('keystone_wsgi_admin').with(
+          'ssl_cert' => 'some cert admin',
+          'ssl_key'  => 'some key admin',
+          )}
+    end
+
     describe 'when overriding parameters using wsgi chunked request' do
       let :params do
         {
